Crate uptrakit_openapi_client

Crate uptrakit_openapi_client 

Re-exports

pub use error::ClientError;
pub use error::Result;
pub use uptrakit_web_api_types as types;

Modules

access_catalog
access_grants
api_tokens
audit_logs
auth
autodiscovery
Client methods for autodiscovery endpoints.
batch_progress_stream
Typed SSE streaming method for batch progress.
discovery_allowlist
Client methods for the discovery plugin allowlist endpoints.
enrollment_tokens
error
events_stream
Typed SSE streaming method for admin events.
health
host_tags
hosts
notifications
oauth_clients
Operator OAuth client management (/api/oauth/clients).
oauth_consents
End-user OAuth authorized-apps management (/api/oauth/consents).
oidc_auth
oidc_providers
pki
plugin_configs
plugin_type_settings
roles
scheduler
services
settings
settings_nats
settings_provider_github
software_items
sse
Lightweight Server-Sent Events (SSE) protocol parser.
surfaces
system_alerts
system_enrollment_tokens
system_services
update_batches
update_history
update_output_stream
Typed SSE streaming method for update output.
users

Structs

RawResponse
Response from a raw (untyped) API request.
ReqwestError
Re-export reqwest::Error so that downstream crates (e.g. the CLI) do not need a direct dependency on reqwest. The Errors that may occur when processing a Request.
RetryConfig
Configuration for automatic retry on transient failures.
StatusCode
Re-export reqwest::StatusCode so that downstream crates (e.g. the CLI) do not need a direct dependency on reqwest for HTTP status handling. An HTTP status code (status-code in RFC 9110 et al.).
UptrakitClient
Typed HTTP client for the Uptrakit web API.
Uuid
Re-export Uuid so that downstream crates can use the exact same type without adding a direct uuid dependency. A Universally Unique Identifier (UUID).

Enums

DeviceAuthStatus
Status of a pending device authorization flow.